/*
 * Copyright 2014-2015 ISP RAS (http://www.ispras.ru)
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */

package ru.ispras.testbase;

import static ru.ispras.fortress.util.InvariantChecks.checkNotNull;

import java.util.List;
import java.util.Collections;

public final class TestBaseQueryResult {

  public enum Status {
    OK, ERROR
  }

  private final Status status;
  private final TestDataProvider dataProvider;
  private final List<String> errors;

  public Status getStatus() {
    return status;
  }

  public boolean hasErrors() {
    return !errors.isEmpty();
  }

  public List<String> getErrors() {
    return errors;
  }

  public TestDataProvider getDataProvider() {
    return dataProvider;
  }

  public static TestBaseQueryResult reportErrors(List<String> errors) {
    checkNotNull(errors);
    return new TestBaseQueryResult(Status.ERROR, TestDataProvider.empty(), errors);
  }

  public static TestBaseQueryResult success(TestDataProvider dataProvider) {
    checkNotNull(dataProvider);
    return new TestBaseQueryResult(Status.OK, dataProvider, Collections.<String>emptyList());
  }

  private TestBaseQueryResult(
      Status status, TestDataProvider dataProvider, List<String> errors) {
    this.status = status;
    this.dataProvider = dataProvider;
    this.errors = errors;
  }
}
